@@ -190,8 +190,6 @@ class Customer(object):
             msg
             ):
         api_request = getattr(REST_CLIENT, method)
-        LOGS.logger.info(api_request)
-        LOGS.logger.info(params)
         response = api_request(
             '/fup',
             auth=(
@@ -537,6 +535,7 @@ class Customer(object):
             infos = groupby(infos, key=lambda x: x['date'])
             for date, data in infos:
                 cdrs[date.strftime('%d%m%Y')] = list(data)
+        LOGS.logger.info("CDRS Recupere")
         return cdrs
 
     def filter_cdrs_policy_wise(self, cdrs, product_out_fup=False):
